@@ -6,9 +6,12 @@ import time
 from crownstone_core.protocol.BlePackets import ControlPacket
 from crownstone_core.protocol.BluenetTypes import ControlType
 
+from crownstone_uart.core.modules.AssetFilterHandler import AssetFilterHandler
 from crownstone_uart.core.modules.ControlHandler import ControlHandler
 from crownstone_uart.core.dataFlowManagers.UartWriter import UartWriter
 from crownstone_uart.core.modules.MeshHandler import MeshHandler
+from crownstone_uart.core.modules.MicroappHandler import MicroappHandler
+from crownstone_uart.core.modules.SetupHandler import SetupHandler
 from crownstone_uart.core.modules.StateHandler import StateHandler
 
 from crownstone_uart.core.dataFlowManagers.StoneManager import StoneManager
@@ -25,7 +28,7 @@ from crownstone_uart.topics.SystemTopics import SystemTopics
 _LOGGER = logging.getLogger(__name__)
 
 class CrownstoneUart:
-    __version__ = "2.4.1"
+    __version__ = "2.5.0"
 
     def __init__(self):
         self.uartManager = None
@@ -37,7 +40,10 @@ class CrownstoneUart:
 
         self.control = ControlHandler()
         self.state = StateHandler()
-        self.mesh = MeshHandler()
+        self.mesh = MeshHandler(self.control)
+        self.setup = SetupHandler(self.control)
+        self.assetFilter = AssetFilterHandler(self.control)
+        self.microapp = MicroappHandler(self.control)
         # only for development. Generally undocumented.
         self._usbDev = UsbDevHandler()
 
@@ -47,9 +53,9 @@ class CrownstoneUart:
     def is_ready(self) -> bool:
         return self.uartManager.is_ready()
 
-    async def initialize_usb(self, port = None, baudrate=230400, writeChunkMaxSize=0):
+    async def initialize_usb(self, port = None, baudrate=230400, writeChunkMaxSize=64):
         """
-        Initialize a Crownstone serial device. 
+        Initialize a Crownstone serial device.
             
         :param port: serial port of the USB. e.g. '/dev/ttyUSB0' or 'COM3'.
         :param baudrate: baudrate that should be used for this connection. default is 230400.
@@ -81,9 +87,9 @@ class CrownstoneUart:
         UartEventBus.unsubscribe(event)
 
 
-    def initialize_usb_sync(self, port = None, baudrate=230400, writeChunkMaxSize=0):
+    def initialize_usb_sync(self, port = None, baudrate=230400, writeChunkMaxSize=64):
         """
-        Initialize a Crownstone serial device. 
+        Initialize a Crownstone serial device.
             
         :param port: serial port of the USB. e.g. '/dev/ttyUSB0' or 'COM3'.
         :param baudrate: baudrate that should be used for this connection. default is 230400.
